@@ -8,7 +8,7 @@
  *  Description: declaration of SHA-1 Secure Hash Algorithm 
  *               external procedures
  *
- *  Revision:   $Id: sha1.h 193 2008-02-04 03:47:57Z pav $
+ *  Revision:   $Id: sha1.h 373 2014-12-23 11:40:21Z nail $
  *
  *  Created:	24-May-2001
  *
@@ -21,6 +21,10 @@
 #ifndef __SHA1_H__
 #define __SHA1_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define SHA1_DIGEST_SIZE        20
 
 #define SHA1_ERROR_NO           0x0
@@ -63,5 +67,8 @@ int SHA1MakeDigest( byte *message, int messageLength, byte *digest );
 #  define ROL( X, n )   ( ( ( X ) << n ) | ( ( X ) >> ( 32 - n ) ) )
 #endif
 
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* __SHA1_H__ */
